# Collections
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/collections#overview)
  * [Collection Structure](https://help.sap.com/docs/leanix/ea/collections#collection-structure)
  * [Permissions](https://help.sap.com/docs/leanix/ea/collections#permissions)
  * [Using Collections](https://help.sap.com/docs/leanix/ea/collections#using-collections)
  * [Managing Collections](https://help.sap.com/docs/leanix/ea/collections#managing-collections)
  * [Importing Collections](https://help.sap.com/docs/leanix/ea/collections#importing-collections)
  * [Best Practice](https://help.sap.com/docs/leanix/ea/collections#best-practice)


Use collections to arrange dashboards, reports, and diagrams into custom groups.
